@@ -5,8 +5,8 @@ from typing import Any, Dict, Type
 from gpt_index.constants import DATA_KEY, TYPE_KEY
 from gpt_index.data_structs.data_structs_v2 import (
     KG,
+    ChatGPTRetrievalPluginIndexDict,
     ChromaIndexDict,
-    OpensearchIndexDict,
     CompositeIndex,
     EmptyIndex,
     FaissIndexDict,
@@ -14,12 +14,13 @@ from gpt_index.data_structs.data_structs_v2 import (
     IndexGraph,
     IndexList,
     KeywordTable,
+    MilvusIndexDict,
+    OpensearchIndexDict,
     PineconeIndexDict,
     QdrantIndexDict,
     SimpleIndexDict,
     V2IndexStruct,
     WeaviateIndexDict,
-    ChatGPTRetrievalPluginIndexDict,
 )
 from gpt_index.data_structs.struct_type import IndexStructType
 from gpt_index.data_structs.table_v2 import PandasStructTable, SQLStructTable
@@ -33,14 +34,15 @@ from gpt_index.indices.struct_store.sql import GPTSQLStructStoreIndex
 from gpt_index.indices.tree.base import GPTTreeIndex
 from gpt_index.indices.vector_store.base import GPTVectorStoreIndex
 from gpt_index.indices.vector_store.vector_indices import (
+    ChatGPTRetrievalPluginIndex,
     GPTChromaIndex,
     GPTFaissIndex,
+    GPTMilvusIndex,
+    GPTOpensearchIndex,
     GPTPineconeIndex,
     GPTQdrantIndex,
     GPTSimpleVectorIndex,
     GPTWeaviateIndex,
-    ChatGPTRetrievalPluginIndex,
-    GPTOpensearchIndex,
 )
 
 INDEX_STRUCT_TYPE_TO_INDEX_STRUCT_CLASS: Dict[IndexStructType, Type[V2IndexStruct]] = {
@@ -52,6 +54,7 @@ INDEX_STRUCT_TYPE_TO_INDEX_STRUCT_CLASS: Dict[IndexStructType, Type[V2IndexStruc
     IndexStructType.WEAVIATE: WeaviateIndexDict,
     IndexStructType.PINECONE: PineconeIndexDict,
     IndexStructType.QDRANT: QdrantIndexDict,
+    IndexStructType.MILVUS: MilvusIndexDict,
     IndexStructType.CHROMA: ChromaIndexDict,
     IndexStructType.OPENSEARCH: OpensearchIndexDict,
     IndexStructType.VECTOR_STORE: IndexDict,
@@ -73,6 +76,7 @@ INDEX_STRUCT_TYPE_TO_INDEX_CLASS: Dict[IndexStructType, Type[BaseGPTIndex]] = {
     IndexStructType.WEAVIATE: GPTWeaviateIndex,
     IndexStructType.PINECONE: GPTPineconeIndex,
     IndexStructType.QDRANT: GPTQdrantIndex,
+    IndexStructType.MILVUS: GPTMilvusIndex,
     IndexStructType.CHROMA: GPTChromaIndex,
     IndexStructType.VECTOR_STORE: GPTVectorStoreIndex,
     IndexStructType.SQL: GPTSQLStructStoreIndex,
