@@ -6,6 +6,7 @@ from gpt_index.indices.vector_store.vector_indices import (
     ChatGPTRetrievalPluginIndex,
     GPTChromaIndex,
     GPTFaissIndex,
+    GPTMilvusIndex,
     GPTOpensearchIndex,
     GPTPineconeIndex,
     GPTQdrantIndex,
@@ -20,6 +21,7 @@ __all__ = [
     "GPTPineconeIndex",
     "GPTWeaviateIndex",
     "GPTQdrantIndex",
+    "GPTMilvusIndex",
     "GPTChromaIndex",
     "GPTOpensearchIndex",
     "ChatGPTRetrievalPluginIndex",
